import { useStripe } from "@stripe/stripe-react-native";
import Constants from "expo-constants";
import React, { useEffect, useState } from "react";
import { Alert, Text, Button, SafeAreaView, View } from "react-native";
import BasketScreen from './screens/BasketScreen';
import Styles from '../styles/Style';
import * as SQLite from 'expo-sqlite';
import { retrieveThemeMode } from './utils/themeUtils';
import {
deleteItem,
deleteAllItems
} from '../database/dbUtils';

export default function CheckoutScreen({ navigation, route }) {
    const { initPaymentSheet, presentPaymentSheet } = useStripe();
    const [loading, setLoading] = useState(false);
    const [paymentIntentId, setPaymentIntentId] = useState<string>("");
    const [isDarkMode, setIsDarkMode] = useState(false);

    const apiUrl = Constants.expoConfig.extra.apiUrl;
    const items = route.params.items;

    const userId = "cus_OsU6FAKAAXp1YI";

    const reformulatedList = items.map((item) => ({
        id: item.id,
        amount: item.quantity
    }));

    const fetchPaymentSheetParams = async () => {
        console.log(items);
        const response = await fetch(`${apiUrl}/payments/`, {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify({
                "pending_items": reformulatedList,
                "customer_id": userId
            })
        });

        const { paymentIntent, ephemeralKey, customer } = await response.json();

        return {
            paymentIntent,
            ephemeralKey,
            customer,
        };
    };

    const initializePaymentSheet = async () => {
        const {
            paymentIntent,
            ephemeralKey,
            customer,
        } = await fetchPaymentSheetParams();

        const { error } = await initPaymentSheet({
            merchantDisplayName: "Example, Inc.",
            customerId: customer,
            customerEphemeralKeySecret: ephemeralKey,
            paymentIntentClientSecret: paymentIntent,
            allowsDelayedPaymentMethods: false,
        });

        if (!error) {
            setPaymentIntentId(paymentIntent);
            setLoading(true);
        }
    };

    const openPaymentSheet = async () => {
        const { error } = await presentPaymentSheet();

        if (error) {
            Alert.alert(`Error code: ${error.code}`, error.message);
        } else {
            const paymentIntent = `pi_${paymentIntentId.split("_")[1]}`;
            const response = await fetch(`${apiUrl}/payments/check/${paymentIntent}`, {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/json',
                },
                body: JSON.stringify({
                    "customer_id": userId
                })
            });

            if (response.status === 200) {
                await deleteAllItems(items);
                navigation.navigate('ScanScreen');
                Alert.alert('Success', 'Your order is confirmed!');
            }
        }
    };

    useEffect(() => {
        initializePaymentSheet();
        retrieveThemeMode().then((themeMode) => {
          setIsDarkMode(themeMode);
        });
    }, []);

    return (
        <View style={isDarkMode ? Styles.darkContainer : Styles.lightContainer}>
          <Button
            color="#E0A228"
            disabled={!loading}
            title="Checkout"
            onPress={openPaymentSheet}
          />
        </View>
    );
}
