import React, { useEffect, useState } from 'react';
import { View, Text, FlatList, StyleSheet } from 'react-native';
import Styles from '../styles/Style';
import { format } from 'date-fns';
import { getPaymentsHistory } from '../database/dbUtils';
import AsyncStorage from '@react-native-async-storage/async-storage';
import Constants from 'expo-constants';
import { retrieveThemeMode } from './utils/themeUtils';

export default function PaymentHistoryScreen() {
  const [paymentHistory, setPaymentHistory] = useState([]);
  const [isDarkMode, setIsDarkMode] = useState(false);
  const apiUrl = Constants.manifest.extra.apiUrl;
  const customerId = "cus_OsU6FAKAAXp1YI";

  useEffect(() => {
    retrieveThemeMode().then((themeMode) => {
        setIsDarkMode(themeMode);
      });
    loadPaymentHistory();
  }, []);

  const loadPaymentHistory = async () => {
    try {
      const response = await fetch(`${apiUrl}/payments/${customerId}`);
      if (response.ok) {
        const history = await response.json();
        console.log(history);
        setPaymentHistory(history);
      } else {
        console.log('Error while retrieving payments history');
      }
    } catch (error) {
      console.log('Error while retrieving payments history', error);
    }
  };

  return (
    <View style={isDarkMode ? Styles.darkContainer : Styles.lightContainer}>
       <FlatList
          data={paymentHistory.reverse()}
          keyExtractor={(item) => item.id}
          renderItem={({ item }) => (
            <View style={isDarkMode ? Styles.historyItemDark : Styles.historyItemLight}>
              <Text style={Styles.itemDate}>
                {format(new Date(item.checkout_date), 'MMMM dd, yyyy HH:mm a')}
              </Text>
              {item.purchased_items.map((purchasedItem, index) => (
                <View key={index} style={Styles.itemInfo}>
                  <Text style={Styles.itemName}>{purchasedItem.item.name}</Text>
                  <Text style={Styles.itemQuantity}>
                    Quantity: {purchasedItem.amount}
                  </Text>
                  <Text style={Styles.itemPrice}>
                    Price: {(purchasedItem.item.price / 100).toFixed(2)} €
                  </Text>
                </View>
              ))}
            </View>
          )}
        />
    </View>
  );
}
